@@ -1,5 +1,5 @@
 package AnyEvent::SlackRTM;
-$AnyEvent::SlackRTM::VERSION = '0.152750';
+$AnyEvent::SlackRTM::VERSION = '0.160720';
 use v5.14;
 
 # ABSTRACT: AnyEvent module for interacting with the Slack RTM API
@@ -38,7 +38,14 @@ sub start {
     );
 
     my $res = $furl->get($START_URL . '?token=' . $self->{token});
-    my $start = decode_json($res->content);
+    my $start = try {
+        decode_json($res->content);
+    }
+    catch {
+        my $status = $res->status;
+        my $message = $res->content;
+        croak "unable to start, Slack call failed: $status $message";
+    };
 
     my $ok  = $start->{ok};
     croak "unable to start, Slack returned an error: $start->{error}"
@@ -51,29 +58,29 @@ sub start {
     my $client = $self->{client};
 
     $client->connect($wss)->cb(sub {
-            my $client = shift;
+        my $client = shift;
 
-            my $conn = try {
-                $client->recv;
-            }
-            catch {
-                die $_;
-            };
+        my $conn = try {
+            $client->recv;
+        }
+        catch {
+            die $_;
+        };
 
-            $self->{started}++;
-            $self->{id} = 1;
+        $self->{started}++;
+        $self->{id} = 1;
 
-            $self->{conn} = $conn;
+        $self->{conn} = $conn;
 
-            $self->{pinger} = AnyEvent->timer(
-                after    => 60,
-                interval => 60,
-                cb       => sub { $self->ping },
-            );
+        $self->{pinger} = AnyEvent->timer(
+            after    => 60,
+            interval => 60,
+            cb       => sub { $self->ping },
+        );
 
-            $conn->on(each_message => sub { $self->_handle_incoming(@_) });
-            $conn->on(finish => sub { $self->_handle_finish(@_) });
-        });
+        $conn->on(each_message => sub { $self->_handle_incoming(@_) });
+        $conn->on(finish => sub { $self->_handle_finish(@_) });
+    });
 }
 
 
@@ -128,16 +135,22 @@ sub send {
 sub ping {
     my ($self, $msg) = @_;
 
-    $self->send({ 
+    $self->send({
         %{ $msg // {} },
-        type => 'ping' 
+        type => 'ping'
     });
 }
 
 sub _handle_incoming {
     my ($self, $conn, $raw) = @_;
 
-    my $msg = decode_json($raw->body);
+    my $msg = try {
+        decode_json($raw->body);
+    }
+    catch {
+        my $message = $raw->body;
+        croak "unable to decode incoming message: $message";
+    };
 
     # Handle the initial hello
     if ($msg->{type} eq 'hello') {
@@ -212,7 +225,7 @@ AnyEvent::SlackRTM - AnyEvent module for interacting with the Slack RTM API
 
 =head1 VERSION
 
-version 0.152750
+version 0.160720
 
 =head1 SYNOPSIS
 
@@ -228,7 +241,7 @@ version 0.152750
     my $i = 1;
     my $keep_alive;
     my $counter;
-    $rtm->on('hello' => sub { 
+    $rtm->on('hello' => sub {
         print "Ready\n";
 
         $keep_alive = AnyEvent->timer(interval => 60, cb => sub {
@@ -241,15 +254,15 @@ version 0.152750
             $rtm->send({
                 type => 'message',
                 channel => $channel_id,
-                text => "".$i++, 
+                text => "".$i++,
             });
         });
     });
-    $rtm->on('message' => sub { 
+    $rtm->on('message' => sub {
         my ($rtm, $message) = @_;
         print "> $message->{text}\n";
     });
-    $rtm->on('finish' => sub { 
+    $rtm->on('finish' => sub {
         print "Done\n";
         $cond->send;
     });
@@ -273,7 +286,7 @@ B<Disclaimer:> Note also that this API is subject to rate limits and any service
 
     method new($token)
 
-Constructs a L<AnyEvent::SlackRTM> object and returns it. 
+Constructs a L<AnyEvent::SlackRTM> object and returns it.
 
 The C<$token> option is the access token from Slack to use. This may be either of the following type of tokens:
 
@@ -359,7 +372,7 @@ Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Qubling Software LLC.
+This software is copyright (c) 2016 by Qubling Software LLC.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
